@@ -119,7 +119,7 @@ class DBConnect:
                 result = self.update_docu(
                     find_docu=find_docu, modify_docu=modify_dict, many=many)
                 if not result['modified_count']:
-                    logging.error('MongoDB(组件)出现删除异常: 没有任何文档被假删除')
+                    logging.warning('MongoDB(组件)出现删除异常: 没有任何文档被假删除')
                 return {'deleted_count': result['modified_count'], 'false_delete': false_delete}
             else:
                 find_docu = handle_db_id(find_docu)
